==> haskell-warp-tls-3.4.9-70-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-warp-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 warp-tls
version:              3.4.9
visibility:           public
id:                   warp-tls-3.4.9-BNxXgxzMwRSBSieot4j7fW
key:                  warp-tls-3.4.9-BNxXgxzMwRSBSieot4j7fW
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             HTTP over TLS support for Warp via the TLS package
description:
    SSLv1 and SSLv2 are obsoleted by IETF.
    We should use TLS 1.2 (or TLS 1.1 or TLS 1.0 if necessary).
    HTTP/2 can be negotiated by ALPN.
    API docs and the README are available at
    <http://www.stackage.org/package/warp-tls>.

category:             Web, Yesod
abi:                  033ac9803a2df4278b83d06b2c35fb45
exposed:              True
exposed-modules:
    Network.Wai.Handler.WarpTLS Network.Wai.Handler.WarpTLS.Internal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/warp-tls-3.4.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/warp-tls-3.4.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/warp-tls-3.4.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-warp-tls
hs-libraries:         HSwarp-tls-3.4.9-BNxXgxzMwRSBSieot4j7fW
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi
    network-3.1.4.0-6CSLlS2XYBeLlFfm0MgCfu
    recv-0.1.0-1RMQzP3pAGmGp56gts4lUI
    streaming-commons-0.2.3.0-18n0yU3DoS0GNSvBxR5zoS
    tls-1.9.0-o0vUsxdxA360IfVVWdacO
    tls-session-manager-0.0.4-3nPzKx4vneXJkoNtM6Azyi
    unliftio-0.2.25.1-4ouS4p8u42FHJEBnZmJiqL
    wai-3.2.4-Di5htLW1xGuJXvFRCFw5eQ warp-3.3.30-6ezHn6BHtWCAzKDo9IvQJP

haddock-interfaces:   /usr/share/doc/haskell-warp-tls/html/warp-tls.haddock
haddock-html:         /usr/share/doc/haskell-warp-tls/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-warp-tls-3.4.9-71-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-warp-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 warp-tls
version:              3.4.9
visibility:           public
id:                   warp-tls-3.4.9-ISwYKGr0JHVJLTTgOvzsuI
key:                  warp-tls-3.4.9-ISwYKGr0JHVJLTTgOvzsuI
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             HTTP over TLS support for Warp via the TLS package
description:
    SSLv1 and SSLv2 are obsoleted by IETF.
    We should use TLS 1.2 (or TLS 1.1 or TLS 1.0 if necessary).
    HTTP/2 can be negotiated by ALPN.
    API docs and the README are available at
    <http://www.stackage.org/package/warp-tls>.

category:             Web, Yesod
abi:                  1abbe0023adf7d05f7cc648a34587610
exposed:              True
exposed-modules:
    Network.Wai.Handler.WarpTLS Network.Wai.Handler.WarpTLS.Internal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/warp-tls-3.4.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/warp-tls-3.4.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/warp-tls-3.4.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-warp-tls
hs-libraries:         HSwarp-tls-3.4.9-ISwYKGr0JHVJLTTgOvzsuI
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi
    network-3.1.4.0-6CSLlS2XYBeLlFfm0MgCfu
    recv-0.1.0-1RMQzP3pAGmGp56gts4lUI
    streaming-commons-0.2.3.0-18n0yU3DoS0GNSvBxR5zoS
    tls-1.9.0-o0vUsxdxA360IfVVWdacO
    tls-session-manager-0.0.4-3nPzKx4vneXJkoNtM6Azyi
    unliftio-0.2.25.1-4ouS4p8u42FHJEBnZmJiqL
    wai-3.2.4-Di5htLW1xGuJXvFRCFw5eQ warp-3.3.30-2F9WVnFrXb042JmtgIncFR

haddock-interfaces:   /usr/share/doc/haskell-warp-tls/html/warp-tls.haddock
haddock-html:         /usr/share/doc/haskell-warp-tls/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
